import { ITerminal } from '@rushstack/node-core-library';
import { ITypingsGeneratorBaseOptions } from '@rushstack/typings-generator';
import { NewlineKind } from '@rushstack/node-core-library';
import { StringValuesTypingsGenerator } from '@rushstack/typings-generator';

/**
 * Get a function that pseudolocalizes a string.
 *
 * @public
 */
export declare function getPseudolocalizer(options: IPseudolocaleOptions): (str: string) => string;

/**
 * @public
 */
export declare type IgnoreStringFunction = (filePath: string, stringName: string) => boolean;

/**
 * @public
 */
export declare interface ILocalizationFile {
    [stringName: string]: ILocalizedString;
}

/**
 * @public
 */
export declare interface ILocalizedString {
    value: string;
    comment?: string;
}

/**
 * @public
 */
export declare interface IParseFileOptions {
    content: string;
    filePath: string;
    /**
     * Optionally, provide a function that will be called for each string. If the function returns `true`
     * the string will not be included.
     */
    ignoreString?: IgnoreStringFunction;
}

/**
 * @public
 */
export declare interface IParseLocFileOptions extends IParseFileOptions, IParseResxOptionsBase {
    parser?: ParserKind;
}

/**
 * @public
 */
export declare interface IParseResxOptions extends IParseFileOptions, IParseResxOptionsBase {
}

/**
 * @public
 */
export declare interface IParseResxOptionsBase {
    terminal: ITerminal;
    resxNewlineNormalization: NewlineKind | undefined;
    ignoreMissingResxComments: boolean | undefined;
}

/**
 * Options for the pseudolocale library.
 *
 * @internalRemarks
 * Eventually this should be replaced with DefinitelyTyped types.
 *
 * @public
 */
export declare interface IPseudolocaleOptions {
    prepend?: string;
    append?: string;
    delimiter?: string;
    startDelimiter?: string;
    endDelimiter?: string;
    extend?: number;
    override?: string;
}

/**
 * @public
 */
export declare interface ITypingsGeneratorOptions extends ITypingsGeneratorBaseOptions {
    exportAsDefault?: boolean;
    resxNewlineNormalization?: NewlineKind | undefined;
    ignoreMissingResxComments?: boolean | undefined;
    ignoreString?: IgnoreStringFunction;
    processComment?: (comment: string | undefined, resxFilePath: string, stringName: string) => string | undefined;
}

/**
 * @public
 */
export declare function parseLocFile(options: IParseLocFileOptions): ILocalizationFile;

/**
 * @public
 */
export declare function parseLocJson({ content, filePath, ignoreString }: IParseFileOptions): ILocalizationFile;

/**
 * @public
 */
export declare function parseResJson({ content, ignoreString, filePath }: IParseFileOptions): ILocalizationFile;

/**
 * @public
 */
export declare function parseResx(options: IParseResxOptions): ILocalizationFile;

/**
 * @public
 */
export declare type ParserKind = 'resx' | 'loc.json' | 'resjson';

/**
 * This is a simple tool that generates .d.ts files for .loc.json, .resx.json, .resjson, and .resx files.
 *
 * @public
 */
export declare class TypingsGenerator extends StringValuesTypingsGenerator {
    constructor(options: ITypingsGeneratorOptions);
}

export { }
